// This is an example Custom Command Qml file. You have full access to the entire Qml language
// for creating any user interface you like. From the ui you can affect the following changes
// with respect to your vehicle:
//    1) Sending COMMAND_LONG commands out over mavlink using QGCButton control
//    2) Modifying parameters
//
// When developing custom Qml file implementations. You must restart QGroundControl to pick up
// the changes. You need to do this even if you select Clear Qml file. Not sure what at the this
// point. Qt must be caching the files somewhere.

import QtQuick 2.2

import QGroundControl.Controls 1.0
import QGroundControl.FactSystem 1.0
import QGroundControl.FactControls 1.0
import QGroundControl.Controllers 1.0


FactPanel {
    id: panel

    property var qgcView: null // Temporary hack for broken QGC parameter validation implementation

    CustomCommandWidgetController { id: controller; factPanel: panel }
    // Your own custom changes start here - everything else above is always required

    Grid{
        columns: 1
        rows: 3

        spacing: 10

        Rectangle{
            width: 475
            height: 70
            color: "black"
            
            Grid {
                columns: 4
                spacing: 8

                // Anchored to 5px off the top right corner of the parent
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 5 // Sets all margins at once
       
                Column {
                    spacing: 5
                
                    Row {
                        QGCButton {
                            text: "          ARM          "
                            onClicked: controller.sendCommand(144, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "STOP FDR"
                            onClicked: controller.sendCommand(252, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
                
                Column {
                    spacing: 5
                    
                    Row {
                        QGCButton {
                            text: "      DISARM      "
                            onClicked: controller.sendCommand(144, 0, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "Data Marker"
                            onClicked: controller.sendCommand(183, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
                
                
                Column {
                    spacing: 5
                    
                    Row {
                        QGCButton {
                            text: "Manual"
                            onClicked: controller.sendCommand(176, 200, 0, 192, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "Trim Save"
                            onClicked: controller.sendCommand(242, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
                    
                Column {
                    spacing: 5
                    
                    Row {
                        QGCButton {
                            text: "Stabilise"
                            onClicked: controller.sendCommand(176, 200, 0, 144, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "Sensor Reset"
                            onClicked: controller.sendCommand(241, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
            }
        }

        Row{
        
            Grid {
                columns: 3
                spacing: 8

                Column {
                    Row {
                        Text{
                            text: "File"
                            color: "white"
                        }
                    }
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "FILE_ON_ARM")
                            width: 210
                        }
                    }
                }

                Column {
                    Row {
                        Text{
                            text: "Software Mode"
                            color: "white"
                        }
                    }
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "CH9_MODE_SW")
                            width: 136
                            font.capitalization: Font.SmallCaps
                        }
                    }
                }

                Column {
                    Row {
                        Text{
                            text: "Speed"
                            color: "white"
                        }
                    }
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "V_TARGET")
                        }
                    }
                }
            }             
        }
        
        Row{

            Grid{
                columns: 5
                spacing: 8

                Column {
                    width: 150
                    spacing: 8

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "ROLL_MAX")
                            width: 60
                        }
                        
                        Text{
                            text: "  Roll Max"
                            color: "white"
                        }
                    }
                    
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "PITCH_MAX")
                            width: 60
                        }
                        
                        Text{
                            text: "  Pitch Max"
                            color: "white"
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YAW_MAX")
                            width: 60
                        }
                        
                        Text{
                            text: "  Yaw Max"
                            color: "white"
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TH_CTRL_EN")
                            width: 60
                        }

                        Text{
                            text: "  RPM Ctrl"
                            color: "white"
                        }
                    }

                    Row{
                    
                        FactTextField {
                            fact: controller.getParameterFact(200, "TELE_PID_TUNE")
                            width: 60
                        }

                        Text{
                            text: "  PID TELE"
                            color: "white"
                        }
                    }

                    Row{
                    
                        FactTextField {
                            fact: controller.getParameterFact(200, "PID_MAN_INPUT")
                            width: 60
                        }

                        Text{
                            text: "  PID Input"
                            color: "white"
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "LP_DATA_SMPLS")
                            width: 60
                        }
                        
                        Text{
                            text: "  Data Filter"
                            color: "white"
                        }
                    }

                    Row {
                        Text{
                            text: "\n Modes:\n   [ 0] off      [ 1] att ctrl\n   [-1] tune   [-2] alt hold"
                            color: "white"
                        }
                    }
                }
                
                // ROLL ANGLE and RATE CONTROLLLER

                Column {
                    spacing: 8
                    width: 98

                    Rectangle{
                        width: 98
                        height: 25
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                text: "Roll Angle ( 0)"
                            }
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text{
                            text: "  P"
                            color: "white"
                        }
                    }
                    
                    Rectangle{
                        width: 98
                        height: 25
                        color: "red"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Roll Rate ( 1)"
                            }
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_P")
                            width: 60
                        }
                        Text{
                            text: "  P"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_I")
                            width: 60
                        }

                        Text{
                            text: "  I"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_D")
                            width: 60
                        }
                        Text{
                            text: "  D"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_IMAX")
                            width: 60
                        }
                        Text{
                            text: "  I max"
                            color: "white"
                        }
                    }
                }
                
                // PITCH ANGLE and RATE CONTROLLLER
                                
                Column {
                    spacing: 8
                    width: 98

                    Rectangle{
                        width: 98
                        height: 25
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Pitch Angle (30)"
                            }
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "P_CTRL_P")
                            width: 60
                        }
                        
                        Text{
                            text: "  P"
                            color: "white"
                        }
                    }
                    
                    Rectangle{
                        width: 98
                        height: 25
                        color: "red"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Pitch Rate (31)"
                            }
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "PR_CTRL_P")
                            width: 60
                        }
                        Text{
                            text: "  P"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "PR_CTRL_I")
                            width: 60
                        }

                        Text{
                            text: "  I"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "PR_CTRL_D")
                            width: 60
                        }
                        Text{
                            text: "  D"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "PR_CTRL_IMAX")
                            width: 60
                        }
                        Text{
                            text: "  I max"
                            color: "white"
                        }
                    }
                }

                // YAW ANGLE and RATE CONTROLLLER
                
                Column {
                    spacing: 8
                    width: 98
                    
                    Rectangle{
                        width: 98
                        height: 25
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                text: "Yaw Angle (10)"
                            }
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "Y_CTRL_P")
                            width: 60
                        }
                        
                        Text{
                            text: "  P"
                            color: "white"
                        }
                    }
                    
                    Rectangle{
                        width: 98
                        height: 25
                        color: "red"

                        Row {
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                text: "Yaw Rate (11)"
                            }
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_P")
                            width: 60
                        }
                        Text{
                            text: "  P"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_I")
                            width: 60
                        }

                        Text{
                            text: "  I"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_D")
                            width: 60
                        }
                        Text{
                            text: "  D"
                            color: "white"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_IMAX")
                            width: 60
                        }
                        Text{
                            text: "  I max"
                            color: "white"
                        }
                    }
                }

            }
        }
    }
    // Your own custom changes end here - everything else below is always required
}
