// This is an example Custom Command Qml file. You have full access to the entire Qml language
// for creating any user interface you like. From the ui you can affect the following changes
// with respect to your vehicle:
//    1) Sending COMMAND_LONG commands out over mavlink using QGCButton control
//    2) Modifying parameters
//
// When developing custom Qml file implementations. You must restart QGroundControl to pick up
// the changes. You need to do this even if you select Clear Qml file. Not sure what at the this
// point. Qt must be caching the files somewhere.

import QtQuick 2.2

import QGroundControl.Controls 1.0
import QGroundControl.FactSystem 1.0
import QGroundControl.FactControls 1.0
import QGroundControl.Controllers 1.0


FactPanel {
    id: panel

    property var qgcView: null // Temporary hack for broken QGC parameter validation implementation

    CustomCommandWidgetController { id: controller; factPanel: panel }
    // Your own custom changes start here - everything else above is always required

    Grid{
        columns: 1
        rows: 3

        spacing: 10

        Rectangle{
            width: 475
            height: 70
            color: "black"
            
            Grid {
                columns: 4
                spacing: 8

                // Anchored to 5px off the top right corner of the parent
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 5 // Sets all margins at once
       
                Column {
                    spacing: 5
                
                    Row {
                        QGCButton {
                            text: "          ARM          "
                            onClicked: controller.sendCommand(144, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "STOP FDR"
                            onClicked: controller.sendCommand(252, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
                
                Column {
                    spacing: 5
                    
                    Row {
                        QGCButton {
                            text: "      DISARM      "
                            onClicked: controller.sendCommand(144, 0, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "Data Marker"
                            onClicked: controller.sendCommand(183, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
                
                
                Column {
                    spacing: 5
                    
                    Row {
                        QGCButton {
                            text: "Manual"
                            onClicked: controller.sendCommand(176, 200, 0, 192, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "Trim Save"
                            onClicked: controller.sendCommand(242, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
                    
                Column {
                    spacing: 5
                    
                    Row {
                        QGCButton {
                            text: "Stabilise"
                            onClicked: controller.sendCommand(176, 200, 0, 144, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                    Row {
                        QGCButton {
                            text: "Sensor Reset"
                            onClicked: controller.sendCommand(241, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                            width: 110
                        }
                    }
                }
            }
        }

        Row{
        
            Grid {
                columns: 3
                spacing: 8

                Column {
                    Row {
                        Text{
                            text: "File"
                            color: "white"
                        }
                    }
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "FILE_ON_ARM")
                            width: 210
                        }
                    }
                }

                Column {
                    Row {
                        Text{
                            text: "Software Mode"
                            color: "white"
                        }
                    }
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "CH9_MODE_SW")
                            width: 136
                            font.capitalization: Font.SmallCaps
                        }
                    }
                }
                
                Column {
                    Row {
                        Text{
                            text: "Speed"
                            color: "white"
                        }
                    }
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "V_TARGET")
                        }
                    }
                }
            }             
        }
        
        Row{
            Grid{
                columns: 3
                spacing: 8

                Column {
                    width: 150
                    spacing: 8

                    Row{

                        FactTextField {
                            fact: controller.getParameterFact(200, "PITCH_MAX")
                            width: 60
                        }
                        
                        Text{
                            text: "  Roll/Pitch Max"
                            color: "white"
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TH_CTRL_EN")
                            width: 60
                        }

                        Text{
                            text: "  Roll Abort"
                            color: "white"
                        }
                    }

                    Row{
                    
                        FactTextField {
                            fact: controller.getParameterFact(200, "TELE_PID_TUNE")
                            width: 60
                        }

                        Text{
                            text: "  Pitch Abort"
                            color: "white"
                        }
                    }

                    Row{
                    
                        FactTextField {
                            fact: controller.getParameterFact(200, "PID_MAN_INPUT")
                            width: 60
                        }

                        Text{
                            text: "  Yaw Abort"
                            color: "white"
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "LP_DATA_SMPLS")
                            width: 60
                        }
                        
                        Text{
                            text: "  Misc 1"
                            color: "white"
                        }
                    }
                    
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "LP_DATA_SMPLS")
                            width: 60
                        }
                        
                        Text{
                            text: "  Misc 2"
                            color: "white"
                        }
                    }
                    
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "LP_DATA_SMPLS")
                            width: 60
                        }
                        
                        Text{
                            text: "  Misc 3"
                            color: "white"
                        }
                    }
                    
                    Row {
                        Text{
                            text: "\n Modes:\n   [ 0] off      [ 1] att ctrl\n   [-1] tune   [-2] alt hold"
                            color: "white"
                        }
                    }
                }
                
                // ELEVATOR PURTURBATIONS

                Column {
                    spacing: 8
                    width: 180

                    Rectangle{
                        width: 180
                        height: 56
                        color: "green"
                        
                        Grid{
                            columns: 1
                            
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once
                            
                            spacing: 6
                            
                            Row {
                                Text{
                                    text: "                 Elevator"
                                    color: "white"
                                }
                            }
                            
                            Row {
                                spacing: 6
                                
                                QGCButton {
                                    text: "3-2-1-1"
                                    onClicked: controller.sendCommand(183, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                                }
                                QGCButton {
                                    text: "one inv."
                                    onClicked: controller.sendCommand(183, 0, 0, 2, 0, 0, 0, 0, 0, 0)
                                }
                                QGCButton {
                                    text: "1-1-2-3"
                                    onClicked: controller.sendCommand(183, 0, 0, 3, 0, 0, 0, 0, 0, 0)
                                }
                            }
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(200, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  E Freq"
                            color: "white"
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  E Dir (-1 Reverse)"
                            color: "white"
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  E Size (-1 Invert)"
                            color: "white"
                        }
                    }

 
                    // RUDDER PURTURBATIONS

                    Row {
                        Rectangle{
                            width: 180
                            height: 56
                            color: "orange"
                            
                            Grid {
                                columns: 1
                                
                                // Anchored to 5px off the top right corner of the parent
                                anchors.left: parent.left
                                anchors.top: parent.top
                                anchors.margins: 5 // Sets all margins at once

                                spacing: 6

                                Row {
                                    Text{
                                        text: "                 Rudder"
                                        color: "white"
                                    }
                                }

                                Row {
                                    spacing: 6
                                    
                                    QGCButton {
                                        text: "no phase"
                                        onClicked: controller.sendCommand(183, 0, 0, 4, 0, 0, 0, 0, 0, 0)
                                    }
                                    QGCButton {
                                        text: "in phase"
                                        onClicked: controller.sendCommand(183, 0, 0, 5, 0, 0, 0, 0, 0, 0)
                                    }
                                    QGCButton {
                                        text: "out inv"
                                        onClicked: controller.sendCommand(183, 0, 0, 6, 0, 0, 0, 0, 0, 0)
                                    }
                                }
                            }
                        }
                    }  
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  R Freq"
                            color: "white"
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  R Dir (-1 Reverse)"
                            color: "white"
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  R Size (-1 Invert)"
                            color: "white"
                        }
                    }
                }
                                 
                // AILERON PURTURBATIONS

                Column {
                    spacing: 8
                    width: 180

                    Rectangle{
                        width: 180
                        height: 56
                        color: "red"
                        
                        Grid {
                            columns: 1
                            
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once
                            
                            spacing: 6
                            
                            Row {
                                Text{
                                    text: "                 Aileron"
                                    color: "white"
                                }
                            }
                            
                            Row {

                                spacing: 6

                                QGCButton {
                                    text: "1-1-1-1 f"
                                    onClicked: controller.sendCommand(183, 0, 0, 7, 0, 0, 0, 0, 0, 0)
                                }
                                QGCButton {
                                    text: "1-1-1-1 s"
                                    onClicked: controller.sendCommand(183, 0, 0, 8, 0, 0, 0, 0, 0, 0)
                                }
                                QGCButton {
                                    text: "1-1 x3"
                                    onClicked: controller.sendCommand(183, 0, 0, 9, 0, 0, 0, 0, 0, 0)
                                }
                            }
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  A Freq"
                            color: "white"
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  A Dir (-1 Reverse)"
                            color: "white"
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  A Size (-1 Invert)"
                            color: "white"
                        }
                    }


                    // LATERAL PHASE PURTURBATIONS

                    Row {
                        Rectangle{
                            width: 180
                            height: 56
                            color: "blue"
                            
                            Grid {
                                columns: 1
                                
                                // Anchored to 5px off the top right corner of the parent
                                anchors.left: parent.left
                                anchors.top: parent.top
                                anchors.margins: 5 // Sets all margins at once
                                    
                                spacing: 6
                                
                                Row {
                                    Text{
                                        text: "                 Lateral Phase"
                                        color: "white"
                                    }
                                }
                                
                                Row {
                                    spacing: 6

                                    QGCButton {
                                        text: "in phase"
                                        onClicked: controller.sendCommand(183, 0, 0, 10, 0, 0, 0, 0, 0, 0)
                                    }
                                    QGCButton {
                                        text: "out ph"
                                        onClicked: controller.sendCommand(183, 0, 0, 11, 0, 0, 0, 0, 0, 0)
                                    }
                                    QGCButton {
                                        text: "test"
                                        onClicked: controller.sendCommand(183, 0, 0, 12, 0, 0, 0, 0, 0, 0)
                                    }
                                }
                            }
                        }
                    }

                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  Lat Freq"
                            color: "white"
                        }
                    }

                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }
                        
                        Text {
                            text: "  Lat Dir (-1 Reverse)"
                            color: "white"
                        }
                    }
                    
                    Row {
                        FactTextField {
                            fact: controller.getParameterFact(150, "R_CTRL_P")
                            width: 60
                        }

                        Text {
                            text: "  Lat Size (-1 Invert)"
                            color: "white"
                        }
                    }
                }               
            }
        }
    }
    // Your own custom changes end here - everything else below is always required
}
