// This is an example Custom Command Qml file. You have full access to the entire Qml language
// for creating any user interface you like. From the ui you can affect the following changes
// with respect to your vehicle:
//    1) Sending COMMAND_LONG commands out over mavlink using QGCButton control
//    2) Modifying parameters
//
// When developing custom Qml file implementations. You must restart QGroundControl to pick up
// the changes. You need to do this even if you select Clear Qml file. Not sure what at the this
// point. Qt must be caching the files somewhere.

import QtQuick 2.2

import QGroundControl.Controls 1.0
import QGroundControl.FactSystem 1.0
import QGroundControl.FactControls 1.0
import QGroundControl.Controllers 1.0


FactPanel {
    id: panel

    property var qgcView: null // Temporary hack for broken QGC parameter validation implementation

    CustomCommandWidgetController { id: controller; factPanel: panel }
    // Your own custom changes start here - everything else above is always required

    Grid{
        columns: 1
        rows: 2

        spacing: 10

        Rectangle{
            width: 2000
            height: 35
            color: "black"

            Row{
                // Anchored to 5px off the top right corner of the parent
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 5 // Sets all margins at once

                spacing: 10

                QGCButton {
                    text: "FSim ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 1, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "DISARM"
                    onClicked: controller.sendCommand(144, 0, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "FILE: "
                    color: "white"
                }
                FactTextField {
                    fact: controller.getParameterFact(200, "FILE_ON_ARM")
                    width: 20
                }

                QGCButton {
                    text: "Manual"
                    onClicked: controller.sendCommand(176, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Stabilize"
                    onClicked: controller.sendCommand(176, 200, 0, 4, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "TECS"
                    onClicked: controller.sendCommand(176, 200, 0, 8, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "RTL"
                    onClicked: controller.sendCommand(176, 200, 0, 16, 1, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "MODE SW: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "CH9_MODE_SW")
                    width: 20
                }

                QGCButton {
                    text: "Data Marker"
                    onClicked: controller.sendCommand(183, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "Speed: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_SPD_TARGET")
                    width: 30
                }
                Text{
                    text: "Alt: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_ALT_TARGET")
                    width: 30
                }

                QGCButton {
                    text: "Sensor Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF OFF"
                    onClicked: controller.sendCommand(241, 200, 0, 2, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Trim Save"
                    onClicked: controller.sendCommand(242, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Quit"
                    onClicked: controller.sendCommand(252, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }
            }
        }

        Row{

            Grid{
                columns: 4
                spacing: 8

                Column {
                    width: 230
                    spacing: 8

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Spd Weight : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "TE_SPD_WEIGHT")
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "TAS min: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "TE_TAS_MIN")
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Roll Abort  : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "ROLL_ABORT")
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Pitch Abort: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "PITCH_ABORT")
                        }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                text: "Constant Spd Glide "
                                color: "white"
                            }
                        }
                    }

                    Rectangle{
                        width: 180
                        height: 35
                        color: "green"

                        Row {

                            spacing: 5

                            FactTextField {
                                fact: controller.getParameterFact(200, "GLIDE_SPD")
                                width: 50
                            }

                            Text{
                                text: " Spd   "
                                color: "white"
                            }

                            FactTextField {
                                fact: controller.getParameterFact(200, "GLIDE_ALT")
                                width: 50
                            }

                            Text{
                                text: " Alt"
                                color: "white"
                            }
                        }
                    }
                    
                    Row {
                            spacing: 32

                            QGCButton {
                                text: "Set up"
                                onClicked: controller.sendCommand(183, 0, 0, 21, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "GO"
                                onClicked: controller.sendCommand(183, 0, 0, 22, 0, 0, 0, 0, 0, 0)
                            }
                        }
                        
                	Row {
                            QGCButton {
                                text: "Abort"
                                onClicked: controller.sendCommand(183, 0, 0, 23, 0, 0, 0, 0, 0, 0)
                                width: 180
                            }
                        }
                        
                    Row {
                    		Text{
                                text: "Glide Alt Lim: "
                                //color: "white"
                            }
                            
                            FactTextField {
                                fact: controller.getParameterFact(200, "GLIDE_LIM")
                                width: 50
                            }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "blue"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                text: "Constant Alt Acceleration"
                                color: "white"
                            }
                        }
                    }

                    Rectangle{
                        width: 180
                        height: 35
                        color: "blue"

                        Row {

                            spacing: 5

                            FactTextField {
                                fact: controller.getParameterFact(200, "ACCEL_SPD")
                                width: 50
                            }

                            Text{
                                text: " Spd   "
                                color: "white"
                            }

                            FactTextField {
                                fact: controller.getParameterFact(200, "ACCEL_ALT")
                                width: 50
                            }

                            Text{
                                text: " Alt"
                                color: "white"
                            }
                        }
                    }

                    Row {
                            spacing: 32

                            QGCButton {
                                text: "Set up"
                                onClicked: controller.sendCommand(183, 0, 0, 25, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "GO"
                                onClicked: controller.sendCommand(183, 0, 0, 26, 0, 0, 0, 0, 0, 0)
                            }
                        }

                    Row {
                            QGCButton {
                                text: "Abort"
                                onClicked: controller.sendCommand(183, 0, 0, 27, 0, 0, 0, 0, 0, 0)
                                width: 180
                            }
                        }
                        
                    Row {
                    		Text{
                                text: "Accel Time Lim: "
                                //color: "white"
                            }
                            
                            FactTextField {
                                fact: controller.getParameterFact(200, "ACCEL_LIM")
                                width: 50
                            }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "red"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                text: "Turn  "
                                color: "white"
                            }

                            FactTextField {
                                fact: controller.getParameterFact(200, "TURN_ANGLE")
                                width: 50
                            }

                            Text{
                                text: "  Angle"
                                color: "white"
                            }
                        }
                    }

                    Rectangle{
                        width: 180
                        height: 35
                        color: "red"

                        Row {

                            spacing: 5

                            FactTextField {
                                fact: controller.getParameterFact(200, "TURN_SPD")
                                width: 50
                            }

                            Text{
                                text: " Spd   "
                                color: "white"
                            }

                            FactTextField {
                                fact: controller.getParameterFact(200, "TURN_ALT")
                                width: 50
                            }

                            Text{
                                text: " Alt"
                                color: "white"
                            }
                        }
                    }

                    Row {
                            spacing: 32

                            QGCButton {
                                text: "Set up"
                                onClicked: controller.sendCommand(183, 0, 0, 31, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "GO"
                                onClicked: controller.sendCommand(183, 0, 0, 32, 0, 0, 0, 0, 0, 0)
                            }
                        }

                    Row {
                            QGCButton {
                                text: "Abort"
                                onClicked: controller.sendCommand(183, 0, 0, 33, 0, 0, 0, 0, 0, 0)
                                width: 180
                            }
                        }

                }
            }
        }
    }
    // Your own custom changes end here - everything else below is always required
}
