// This is an example Custom Command Qml file. You have full access to the entire Qml language
// for creating any user interface you like. From the ui you can affect the following changes
// with respect to your vehicle:
//    1) Sending COMMAND_LONG commands out over mavlink using QGCButton control
//    2) Modifying parameters
//
// When developing custom Qml file implementations. You must restart QGroundControl to pick up
// the changes. You need to do this even if you select Clear Qml file. Not sure what at the this
// point. Qt must be caching the files somewhere.

import QtQuick 2.2

import QGroundControl.Controls 1.0
import QGroundControl.FactSystem 1.0
import QGroundControl.FactControls 1.0
import QGroundControl.Controllers 1.0


FactPanel {
    id: panel

    property var qgcView: null // Temporary hack for broken QGC parameter validation implementation

    CustomCommandWidgetController { id: controller; factPanel: panel }
    // Your own custom changes start here - everything else above is always required

    Grid{
        columns: 1
        rows: 2

        spacing: 10

        Rectangle{
            width: 2000
            height: 35
            color: "black"

            Row{
                // Anchored to 5px off the top right corner of the parent
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 5 // Sets all margins at once

                spacing: 10

                QGCButton {
                    text: "FSim ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 1, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "DISARM"
                    onClicked: controller.sendCommand(144, 0, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "FILE: "
                    color: "white"
                }
                FactTextField {
                    fact: controller.getParameterFact(200, "FILE_ON_ARM")
                    width: 20
                }

                QGCButton {
                    text: "Manual"
                    onClicked: controller.sendCommand(176, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Stabilize"
                    onClicked: controller.sendCommand(176, 200, 0, 4, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "TECS"
                    onClicked: controller.sendCommand(176, 200, 0, 8, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "RTL"
                    onClicked: controller.sendCommand(176, 200, 0, 16, 1, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "MODE SW: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "CH9_MODE_SW")
                    width: 20
                }

                QGCButton {
                    text: "Data Marker"
                    onClicked: controller.sendCommand(183, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "Speed: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_SPD_TARGET")
                    width: 30
                }
                Text{
                    text: "Alt: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_ALT_TARGET")
                    width: 30
                }

                QGCButton {
                    text: "Sen. Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF OFF"
                    onClicked: controller.sendCommand(241, 200, 0, 2, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Trim Save"
                    onClicked: controller.sendCommand(242, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Quit"
                    onClicked: controller.sendCommand(252, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }
            }
        }

        Row{

            Grid{
                columns: 5
                spacing: 8

                Column {
                    width: 180
                    spacing: 8

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Tune Spd.  : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "TAS_CRUISE")
                            width: 50
                        }
                    }

                    Row{

                        Text{
                            text: "Roll Trim    : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "ROLL_TRIM")
                            width: 70
                        }
                    }

                    Row{
                        Text{
                            text: "Yaw Trim   : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "YAW_TRIM")
                            width: 70
                        }

                    }

                    Row{
                        Text{
                            //anchors.top: parent.top + 3
                            text: "PID TELE   : "
                            color: "blue"
                        }
                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "TELE_PID_TUNE")
                            width: 50
                        }
                    }

                    Row{
                        Text{
                            //anchors.top: parent.top + 3
                            text: "PID Input   : "
                            color: "blue"
                        }
                        FactTextField {
                            fact: controller.getParameterFact(200, "PID_MAN_INPUT")
                            width: 50
                        }
                    }
                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                text: "Roll PID (0):\t"
                                color: "white"
                            }
                            FactTextField {
                                fact: controller.getParameterFact(200, "R_CTRL_EN")
                                width: 30
                            }

                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "R_CTRL_P")
                            width: 50
                        }
                        Text{
                            text: "  Kp\t"
                            color: "blue"
                        }

                        Text{
                            text: " R Max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "R_CTRL_I")
                            width: 50
                        }

                        Text{
                            text: "  Ki\t"
                            color: "blue"
                        }

                        FactTextField {
                            fact: controller.getParameterFact(200, "ROLL_MAX")
                            width: 50
                        }

                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "R_CTRL_D")
                            width: 50
                        }
                        Text{
                            text: "  Kd\t"
                            color: "blue"
                        }

                        Text{
                            text: " RR Max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "R_CTRL_IMAX")
                            width: 50
                        }
                        Text{
                            text: "  Ki max\t"
                            color: "blue"
                        }
                        FactTextField {
                            fact: controller.getParameterFact(200, "ROLL_RATE_MAX")
                            width: 50
                        }
                    }
                    Row{
                        Text{
                            text: "   Modes: [0] off, [1] att ctrl, [-1] tune"
                            color: "blue"
                        }
                    }
                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Roll Rate PID (1):\t\t"
                                color: "white"
                            }

                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_P")
                            width: 50
                        }
                        Text{
                            text: "  Kp"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_I")
                            width: 50
                        }

                        Text{
                            text: "  Ki"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_D")
                            width: 50
                        }
                        Text{
                            text: "  Kd"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "RR_CTRL_IMAX")
                            width: 50
                        }
                        Text{
                            text: "  Ki max"
                            color: "blue"
                        }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "red"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "YAW PID (10): "
                                color: "white"
                            }

                            FactTextField {
                                fact: controller.getParameterFact(200, "Y_CTRL_EN")
                                width: 30
                            }

                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "Y_CTRL_P")
                            width: 50
                        }
                        Text{
                            text: "  Kp\t"
                            color: "blue"
                        }

                         Text{
                            text: " Y Max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "Y_CTRL_I")
                            width: 50
                        }

                        Text{
                            text: "  Ki\t"
                            color: "blue"
                        }

                        FactTextField {
                            fact: controller.getParameterFact(200, "YAW_MAX")
                            width: 50
                        }

                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "Y_CTRL_D")
                            width: 50
                        }
                        Text{
                            text: "  Kd\t"
                            color: "blue"
                        }
                        Text{
                            text: " YR Max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "Y_CTRL_IMAX")
                            width: 50
                        }
                        Text{
                            text: "  Ki max\t"
                            color: "blue"
                        }
                        FactTextField {
                            fact: controller.getParameterFact(200, "YAW_RATE_MAX")
                            width: 50
                        }
                    }
                    Row{
                        Text{
                            text: "   Modes: [0] no ctrl, [1] rate ctrl, [-1] tune"
                            color: "blue"
                        }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "red"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Yaw Rate PID (11): "
                                color: "white"
                            }

                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_P")
                            width: 50
                        }
                        Text{
                            text: "  Kp"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_I")
                            width: 50
                        }

                        Text{
                            text: "  Ki"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_D")
                            width: 50
                        }
                        Text{
                            text: "  Kd"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "YR_CTRL_IMAX")
                            width: 50
                        }
                        Text{
                            text: "  Ki max"
                            color: "blue"
                        }
                    }

                }
            }
        }
    }
    // Your own custom changes end here - everything else below is always required
}
