// This is an example Custom Command Qml file. You have full access to the entire Qml language
// for creating any user interface you like. From the ui you can affect the following changes
// with respect to your vehicle:
//    1) Sending COMMAND_LONG commands out over mavlink using QGCButton control
//    2) Modifying parameters
//
// When developing custom Qml file implementations. You must restart QGroundControl to pick up
// the changes. You need to do this even if you select Clear Qml file. Not sure what at the this
// point. Qt must be caching the files somewhere.

import QtQuick 2.2

import QGroundControl.Controls 1.0
import QGroundControl.FactSystem 1.0
import QGroundControl.FactControls 1.0
import QGroundControl.Controllers 1.0


FactPanel {
    id: panel

    property var qgcView: null // Temporary hack for broken QGC parameter validation implementation

    CustomCommandWidgetController { id: controller; factPanel: panel }
    // Your own custom changes start here - everything else above is always required

    Grid{
        columns: 1
        rows: 2

        spacing: 10

        Rectangle{
            width: 2000
            height: 35
            color: "black"

            Row{
                // Anchored to 5px off the top right corner of the parent
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 5 // Sets all margins at once

                spacing: 10

                QGCButton {
                    text: "FSim ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 1, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "DISARM"
                    onClicked: controller.sendCommand(144, 0, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "FILE: "
                    color: "white"
                }
                FactTextField {
                    fact: controller.getParameterFact(200, "FILE_ON_ARM")
                    width: 20
                }

                QGCButton {
                    text: "Manual"
                    onClicked: controller.sendCommand(176, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Stabilize"
                    onClicked: controller.sendCommand(176, 200, 0, 4, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "TECS"
                    onClicked: controller.sendCommand(176, 200, 0, 8, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "RTL"
                    onClicked: controller.sendCommand(176, 200, 0, 16, 1, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "MODE SW: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "CH9_MODE_SW")
                    width: 20
                }

                QGCButton {
                    text: "Data Marker"
                    onClicked: controller.sendCommand(183, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "Speed: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_SPD_TARGET")
                    width: 30
                }
                Text{
                    text: "Alt: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_ALT_TARGET")
                    width: 30
                }

                QGCButton {
                    text: "Sensor Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF OFF"
                    onClicked: controller.sendCommand(241, 200, 0, 2, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Trim Save"
                    onClicked: controller.sendCommand(242, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Quit"
                    onClicked: controller.sendCommand(252, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }
            }
        }

        Row{

            Grid{
                columns: 5
                spacing: 8

                Column {
                    width: 200
                    spacing: 8

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "TIme const : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "TE_TIME_CONST")
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Spd Weight: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "TE_SPD_WEIGHT")
                        }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Tecs limits "
                            }
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_TAS_MAX")
                        }
                        Text{
                            text: "  Spd max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_TAS_MIN")
                        }

                        Text{
                            text: "  Spd min"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_PITCH_MAX")
                        }
                        Text{
                            text: "  Pi max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_PITCH_MIN")
                        }
                        Text{
                            text: "  Pi min"
                            color: "blue"
                        }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "More Limits "
                            }

                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_THR_MAX")
                        }
                        Text{
                            text: "  Thr max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_THR_MIN")
                        }

                        Text{
                            text: "  Thr min"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_THR_SLEW")
                        }
                        Text{
                            text: "  Thr slew"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_THR_DAMP")
                        }
                        Text{
                            text: "  Thr damp"
                            color: "blue"
                        }
                    }

                }
                
                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "yellow"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Settings "
                            }

                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_PITCH_DAMP")
                        }

                        Text{
                            text: "  P damp"
                            color: "blue"
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_MAX_CLIMB_R")
                        }

                        Text{
                            text: "  Clmb max"
                            color: "blue"
                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_MAX_SINK_R")
                        }
                        Text{
                            text: "  Sink max"
                            color: "blue"
                        }
                    }
                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_MIN_SINK_R")
                        }
                        Text{
                            text: "  Sink min"
                            color: "blue"
                        }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 180
                        height: 35
                        color: "yellow"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            Text{
                                //anchors.top: parent.top + 3
                                text: "Settings "
                            }

                        }
                    }

                    Row{
                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_INT_GAIN")
                        }
                        Text{
                            text: "  I gain"
                            color: "blue"
                        }
                    }

                    Row{

                        FactTextField {

                            fact: controller.getParameterFact(200, "TE_VERT_A_LIM")
                        }

                        Text{
                            text: "  Az lim"
                            color: "blue"
                        }

                    }

                    Row{

                        FactTextField {
                            fact: controller.getParameterFact(200, "TE_ROLL_CMP")
                        }

                        Text{
                            text: "  Roll cmp"
                            color: "blue"
                        }
                }


                }
            }
        }
    }
    // Your own custom changes end here - everything else below is always required
}
