// This is an example Custom Command Qml file. You have full access to the entire Qml language
// for creating any user interface you like. From the ui you can affect the following changes
// with respect to your vehicle:
//    1) Sending COMMAND_LONG commands out over mavlink using QGCButton control
//    2) Modifying parameters
//
// When developing custom Qml file implementations. You must restart QGroundControl to pick up
// the changes. You need to do this even if you select Clear Qml file. Not sure what at the this
// point. Qt must be caching the files somewhere.

import QtQuick 2.2

import QGroundControl.Controls 1.0
import QGroundControl.FactSystem 1.0
import QGroundControl.FactControls 1.0
import QGroundControl.Controllers 1.0


FactPanel {
    id: panel

    property var qgcView: null // Temporary hack for broken QGC parameter validation implementation

    CustomCommandWidgetController { id: controller; factPanel: panel }
    // Your own custom changes start here - everything else above is always required

    Grid{
        columns: 1
        rows: 2

        spacing: 10

        Rectangle{
            width: 2000
            height: 35
            color: "black"

            Row{
                // Anchored to 5px off the top right corner of the parent
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 5 // Sets all margins at once

                spacing: 10

                QGCButton {
                    text: "FSim ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 1, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "ARM"
                    onClicked: controller.sendCommand(144, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "DISARM"
                    onClicked: controller.sendCommand(144, 0, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "FILE: "
                    color: "white"
                }
                FactTextField {
                    fact: controller.getParameterFact(200, "FILE_ON_ARM")
                    width: 20
                }

                QGCButton {
                    text: "Manual"
                    onClicked: controller.sendCommand(176, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Stabilize"
                    onClicked: controller.sendCommand(176, 200, 0, 4, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "TECS"
                    onClicked: controller.sendCommand(176, 200, 0, 8, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "RTL"
                    onClicked: controller.sendCommand(176, 200, 0, 16, 1, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "MODE SW: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "CH9_MODE_SW")
                    width: 20
                }

                QGCButton {
                    text: "Data Marker"
                    onClicked: controller.sendCommand(183, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                Text{
                    text: "Speed: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_SPD_TARGET")
                    width: 30
                }
                Text{
                    text: "Alt: "
                    color: "white"
                }

                FactTextField {
                    fact: controller.getParameterFact(200, "TE_ALT_TARGET")
                    width: 30
                }

                QGCButton {
                    text: "Sensor Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF Reset"
                    onClicked: controller.sendCommand(241, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }
                
                QGCButton {
                    text: "EKF OFF"
                    onClicked: controller.sendCommand(241, 200, 0, 2, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Trim Save"
                    onClicked: controller.sendCommand(242, 200, 0, 0, 0, 0, 0, 0, 0, 0)
                }

                QGCButton {
                    text: "Quit"
                    onClicked: controller.sendCommand(252, 200, 0, 1, 0, 0, 0, 0, 0, 0)
                }

            }
        }

        Row{

            Grid{
                columns: 6
                spacing: 8

                Column {
                    width: 160
                    spacing: 8

                    Row{

                        Text{
                            text: "Inp. Mode: "
                            color: "blue"
                        }

                        FactTextField {
                            fact: controller.getParameterFact(200, "INPUT_MODE")
                            width: 40
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Roll Abort  : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "ROLL_ABORT")
                            width: 50
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Pitch Abort: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "PITCH_ABORT")
                            width: 50
                        }
                    }

                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 260
                        height: 35
                        color: "green"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            QGCButton {
                                text: "EL 1"
                                onClicked: controller.sendCommand(183, 0, 0, 1, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "EL 2"
                                onClicked: controller.sendCommand(183, 0, 0, 2, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "EL sine"
                                onClicked: controller.sendCommand(183, 0, 0, 3, 0, 0, 0, 0, 0, 0)
                            }
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "E Freq: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "ELEV_BASE_FREQ")
                            width: 50
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "E Dir   : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "ELEV_DIR")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-1) reverse"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "E Size: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "ELEV_SIZE")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-) invert"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "E F_cut: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "ELEV_F_CUT")
                            width: 50
                        }
                    }
                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 260
                        height: 35
                        color: "orange"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            QGCButton {
                                text: "Rd 1"
                                onClicked: controller.sendCommand(183, 0, 0, 4, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Rd 2"
                                onClicked: controller.sendCommand(183, 0, 0, 5, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Rd sine"
                                onClicked: controller.sendCommand(183, 0, 0, 6, 0, 0, 0, 0, 0, 0)
                            }
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "R Freq: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "RUDD_BASE_FREQ")
                            width: 50
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "R Dir   : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "RUDD_DIR")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: "(-1) reverse"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "R Size: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "RUDD_SIZE")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-) invert"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "R F_cut: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "RUDD_F_CUT")
                            width: 50
                        }
                    }
                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 260
                        height: 35
                        color: "red"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            QGCButton {
                                text: "Ail 1"
                                onClicked: controller.sendCommand(183, 0, 0, 7, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Ail 2"
                                onClicked: controller.sendCommand(183, 0, 0, 8, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Ail sine"
                                onClicked: controller.sendCommand(183, 0, 0, 9, 0, 0, 0, 0, 0, 0)
                            }
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "A Freq: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "AIL_BASE_FREQ")
                            width: 50
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "A Dir   : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "AIL_DIR")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: "(-1) reverse"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "A Size: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "AIL_SIZE")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-) invert"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "A F_cut: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "AIL_F_CUT")
                            width: 50
                        }
                    }
                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 260
                        height: 35
                        color: "yellow"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            QGCButton {
                                text: "Lat skew 1"
                                onClicked: controller.sendCommand(183, 0, 0, 10, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Lat skew 2"
                                onClicked: controller.sendCommand(183, 0, 0, 11, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Lat sine"
                                onClicked: controller.sendCommand(183, 0, 0, 12, 0, 0, 0, 0, 0, 0)
                            }
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Lat Dir   : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "LAT_DIR")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-1) reverse"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Lat Size: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "LAT_SIZE")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-) invert"
                            color: "blue"
                        }
                    }
                }

                Column {
                    spacing: 8

                    Rectangle{
                        width: 260
                        height: 35
                        color: "white"

                        Row {
                            // Anchored to 5px off the top right corner of the parent
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.margins: 5 // Sets all margins at once

                            spacing: 16

                            QGCButton {
                                text: "Thr step 1"
                                onClicked: controller.sendCommand(183, 0, 0, 13, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Thr step 2"
                                onClicked: controller.sendCommand(183, 0, 0, 14, 0, 0, 0, 0, 0, 0)
                            }
                            QGCButton {
                                text: "Thr sine"
                                onClicked: controller.sendCommand(183, 0, 0, 15, 0, 0, 0, 0, 0, 0)
                            }
                        }
                    }
/*
                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Lat Freq: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "AIL_BASE_FREQ")
                            width: 50
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Lat Dir   : "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "LAT_DIR")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-1) reverse"
                            color: "blue"
                        }
                    }

                    Row{

                        Text{
                            //anchors.top: parent.top + 3
                            text: "Lat Size: "
                            color: "blue"
                        }

                        FactTextField {
                            // The -1 signals default component id.
                            // You can replace it with a specific component id if you like
                            fact: controller.getParameterFact(200, "LAT_SIZE")
                            width: 50
                        }

                        Text{
                            //anchors.top: parent.top + 3
                            text: " (-) invert"
                            color: "blue"
                        }
                    }*/
                }

            }
        }
    }
    // Your own custom changes end here - everything else below is always required
}
